from setuptools import setup

setup(
    name='mosaiq',
    version='0.1-3',
    install_requires=['pandas', 'matplotlib'],
    license=['MIT'],
    url=['https://github.com/jdonaldson/mosaiq-python'],
    author=["Justin Donaldson"],
    packages=["mosaiq"],
    author_email=['jdonaldson@gmail.com'],
)
